// This file was generated by gir (https://github.com/gtk-rs/gir)
// from gir-files (https://github.com/gtk-rs/gir-files.git)
// DO NOT EDIT

pub fn version() -> &'static str {
if cfg!(feature = "v4_6") {
        "4.6"
    } else if cfg!(feature = "v4_4") {
        "4.4"
    } else if cfg!(feature = "v4_2") {
        "4.2"
    } else {
        "4"
    }
}
